@@ -4,7 +4,7 @@ estimates.Jointlcmm <- function(x,cholesky=TRUE)
  if (!inherits(x, "Jointlcmm")) stop("use only with \"Jointlcmm\" objects")
  if(is.na(as.logical(cholesky))) stop("cholesky should be TRUE or FALSE")
 
- if(x$conv==1 | x$conv==2)
+ if(x$conv==1 | x$conv==2 | x$conv==3)
  {
   res <- x$best
   cholesky <- as.logical(cholesky)
